@@ -1,6 +1,6 @@
 /* savedir.c -- save the list of files in a directory in a string
 
-   Copyright 1990, 1997, 1998, 1999, 2000, 2001 Free Software
+   Copyright 1990, 1997, 1998, 1999, 2000, 2001, 2003 Free Software
    Foundation, Inc.
 
    This program is free software; you can redistribute it and/or modify
@@ -56,9 +56,7 @@ extern int errno;
 # include <stdlib.h>
 # include <string.h>
 #endif
-#ifndef NULL
-# define NULL 0
-#endif
+#include <stddef.h>
 
 #include "savedir.h"
 #include "xalloc.h"
