@@ -1,5 +1,5 @@
 /* stty -- change and print terminal line settings
-   Copyright (C) 1990-2002 Free Software Foundation, Inc.
+   Copyright (C) 1990-2003 Free Software Foundation, Inc.
 
    This program is free software; you can redistribute it and/or modify
    it under the terms of the GNU General Public License as published by
@@ -52,19 +52,13 @@
 # include <sys/pty.h>
 #endif
 #include <getopt.h>
-#if PROTOTYPES
-# include <stdarg.h>
-# define VA_START(args, lastarg) va_start(args, lastarg)
-#else
-# include <varargs.h>
-# define VA_START(args, lastarg) va_start(args)
-#endif
+#include <stdarg.h>
+#define VA_START(args, lastarg) va_start(args, lastarg)
 
 #include "system.h"
 #include "long-options.h"
 #include "error.h"
 #include "xstrtol.h"
-#include "closeout.h"
 
 /* The official name of this program (e.g., no `g' prefix).  */
 #define PROGRAM_NAME "stty"
@@ -407,34 +401,31 @@ static struct control_info control_info[] =
   {NULL, 0, 0}
 };
 
-static const char *visible PARAMS ((unsigned int ch));
-static unsigned long baud_to_value PARAMS ((speed_t speed));
-static int recover_mode PARAMS ((char *arg, struct termios *mode));
-static int screen_columns PARAMS ((void));
-static int set_mode PARAMS ((struct mode_info *info, int reversed,
-			     struct termios *mode));
-static long integer_arg PARAMS ((const char *s));
-static speed_t string_to_baud PARAMS ((const char *arg));
-static tcflag_t *mode_type_flag PARAMS ((enum mode_type type,
-					 struct termios *mode));
-static void display_all PARAMS ((struct termios *mode, int fd,
-				 const char *device_name));
-static void display_changed PARAMS ((struct termios *mode));
-static void display_recoverable PARAMS ((struct termios *mode));
-static void display_settings PARAMS ((enum output_type output_type,
-				      struct termios *mode, int fd,
-				      const char *device_name));
-static void display_speed PARAMS ((struct termios *mode, int fancy));
-static void display_window_size PARAMS ((int fancy, int fd,
-					 const char *device_name));
-static void sane_mode PARAMS ((struct termios *mode));
-static void set_control_char PARAMS ((struct control_info *info,
-				      const char *arg,
-				      struct termios *mode));
-static void set_speed PARAMS ((enum speed_setting type, const char *arg,
-			       struct termios *mode));
-static void set_window_size PARAMS ((int rows, int cols, int fd,
- 				  const char *device_name));
+static const char *visible (unsigned int ch);
+static unsigned long baud_to_value (speed_t speed);
+static int recover_mode (char *arg, struct termios *mode);
+static int screen_columns (void);
+static int set_mode (struct mode_info *info, int reversed,
+			     struct termios *mode);
+static long integer_arg (const char *s);
+static speed_t string_to_baud (const char *arg);
+static tcflag_t *mode_type_flag (enum mode_type type, struct termios *mode);
+static void display_all (struct termios *mode, int fd, const char *device_name);
+static void display_changed (struct termios *mode);
+static void display_recoverable (struct termios *mode);
+static void display_settings (enum output_type output_type,
+			      struct termios *mode, int fd,
+			      const char *device_name);
+static void display_speed (struct termios *mode, int fancy);
+static void display_window_size (int fancy, int fd, const char *device_name);
+static void sane_mode (struct termios *mode);
+static void set_control_char (struct control_info *info,
+			      const char *arg,
+			      struct termios *mode);
+static void set_speed (enum speed_setting type, const char *arg,
+		       struct termios *mode);
+static void set_window_size (int rows, int cols, int fd,
+			     const char *device_name);
 
 /* The width of the screen, for output wrapping. */
 static int max_col;
@@ -453,19 +444,16 @@ static struct option longopts[] =
 /* The name this program was run with. */
 char *program_name;
 
+static void wrapf (const char *message, ...)
+     __attribute__ ((__format__ (__printf__, 1, 2)));
+
 /* Print format string MESSAGE and optional args.
    Wrap to next line first if it won't fit.
    Print a space first unless MESSAGE will start a new line. */
 
 /* VARARGS */
 static void
-#if PROTOTYPES
 wrapf (const char *message,...)
-#else
- wrapf (message, va_alist)
-     const char *message;
-     va_dcl
-#endif
 {
   va_list args;
   char buf[1024];		/* Plenty long for our needs. */
@@ -714,7 +702,7 @@ settings, CHAR is taken literally, or coded as in ^c, 0x37, 0177 or\n\
 }
 
 /* Return 1 if the string contains only valid options.  */
-int
+static int
 valid_options (char *opt, const char *valid_opts,
 	       const char *valid_arg_opts)
 {
@@ -753,6 +741,7 @@ main (int argc, char **argv)
   const char *posixly_correct = getenv ("POSIXLY_CORRECT");
   int invalid_long_option = 0;
 
+  initialize_main (&argc, &argv);
   program_name = argv[0];
   setlocale (LC_ALL, "");
   bindtextdomain (PACKAGE, LOCALEDIR);
@@ -827,7 +816,7 @@ main (int argc, char **argv)
 	  if (k < argc - 1)
 	    noargs = 0;
 	  break;
-    	}
+	}
 
       /* Handle "--file device" */
       len = strlen (argv[k]);
@@ -836,7 +825,7 @@ main (int argc, char **argv)
 	  argv[k] = NULL;
 	  argv[k + 1] = NULL;
 	  continue;
-    	}
+	}
 
       /* Handle "--all" and "--save".  */
       if (len >= 3
