@@ -21,12 +21,10 @@
 
 #include <stdio.h>
 #include <assert.h>
-#include <errno.h>
 #include <sys/types.h>
 #include <getopt.h>
 
 #include "system.h"
-#include "closeout.h"
 #include "error.h"
 #include "safe-read.h"
 #include "xstrtol.h"
